﻿using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.Drawing.Printing;
using System.Windows.Forms;
using System.Runtime.InteropServices;
using System.Text.RegularExpressions;
using System.Linq;
using System.Collections.Generic;
using System.IO;

//Author: James Rogers, St. Norbert College '18, Computer Science, Graphic Design Double Major
//Class: CSCI 460
//Completed over the Spring 2018 semester
//Assistance and guidance from Dr. Dave Pankratz and Dr. Bonita McVey

namespace Capstone4602._0._1
{

    /// <summary>
    /// Capstone Project Version 2.0.1 - Illustrating Text By Tag Clouds
    /// This program maily utilizes two controls in Windows Forms - Labels and the GroupBox
    /// The main goal of the program is to interpret textual data and place it into a tag cloud
    /// in a way that is pleasing to the eye and downloadable.
    /// The tag cloud is customizeable in a number of ways - Font, Shape, and Color.
    /// How the process works - The main path for the program flow
    /// 1. Data read in from two separate .txt sources that are tied together - can be found in debug folder
    /// 2. User hits the RUN button
    /// 3. Program creates empty labels within GroupBox according to quantity given by the user (starts at max of 300)(generateLabel())
    /// 4. Program places data into each label according to quantity
    /// 5. Program places labels into the groupbox according to random placement and zone increments (arrange label(generateLabel()))
    /// 5.5 Program will recursively call placement function until labels are placed
    /// 6. Program condenses labels towards center (condense())
    /// 7. once all words are placed, user has opportunity to save tag cloud 
    /// 8. User then also has opportunity to change tag cloud shape, color, font, and data source
    /// </summary>

    public partial class Form1 : Form
    {
        //NOTE AFTER PRESENTATION - CHANGE SIZE OF FONT BASED ON WORD QUANTITY
        //Lower quantity = larger font size, Larger quantity = smaller font size

        //////////////GLOBAL VARIABLES////////////////

        //boolean to detect whether user has changed to a shaped background
        bool ShapeBack = false;
        //global image variables to initialize a bitmap only when user needs it
        Bitmap map;
        Image defaultBackgroundImage;
        Image original;
        //factor to multiply word size
        int fontMult = 7;
        //integer to identify which source the words are coming from
        public int SourceChoice = 1;
        //for checking on words printed
        public int totalWordQuantity = 0;
        public int MaxWords = 299;
        //keeping track of collisions and changing the placement zone
        public int totalMisses = 0;
        public int setMisses = 0;
        public int Increment = 10;  //seems to work best to split group box into 10 increments
        public int incHeight = 28;  //comes from cutting the halfway zone making it about ten increments until the boarder is reached
        public int incWidth = 42;   //same as above
        //to make the label exist in the first place
        public int xCoord = 1;
        public int yCoord = 1;
        public Point hold;
        //when the algorithm was more random based
        public const int MAXFONT = 35; //not used anymore
        public const int MINFONT = 2;  //not used anymore
        //dont let words go past bounds of GroupBox
        public int MINWIDTH = 5;
        public int MINHEIGHT = 5;
        public int MAXWIDTH = 850;
        public int MAXHEIGHT = 580;
        //needed for random placement
        Random rnd = new Random();
        //color array - should make more user customizable
        public Color[] ColorArray = new Color[] { Color.Crimson, Color.Blue, Color.MediumPurple };
        //font array 
        public string[] FontArray = new string[] {"Stencil", "Times New Roman", "Microsoft Sans Serif", "Wingdings", "Impact", "Harlow Solid Italic" , "Cooper Black" , "Comic Sans MS"};
        public string MasterFont = "Stencil";
        //Very important!! keeps track of place in word and number arrays
        public int ArrayPlace = 0;
        //declared data arrays which are to be loaded in by readInstances()
        string[] WordArray = new string[300]; //actual words
        int[] QuantityArray = new int[300];   //quantities of words

        //Win32 needed for pixel color catching, within getColorFromScreen(point)
        public class Win32
        {
            [DllImport("user32.dll")]
            static extern IntPtr GetDC(IntPtr hwnd);

            [DllImport("user32.dll")]
            static extern Int32 ReleaseDC(IntPtr hwnd, IntPtr hdc);

            [DllImport("gdi32.dll")]
            static extern uint GetPixel(IntPtr hdc, int nXPos, int nYPos);

            //very important function for detecting color within shape for shaped tag clouds
            static public Color GetPixelColor(int x, int y)
            {
                IntPtr hdc = GetDC(IntPtr.Zero);
                uint pixel = GetPixel(hdc, x, y);
                ReleaseDC(IntPtr.Zero, hdc);
                Color color = Color.FromArgb((int)(pixel & 0x000000FF),
                             (int)(pixel & 0x0000FF00) >> 8,
                             (int)(pixel & 0x00FF0000) >> 16);
                return color;
            }
        }


        public Form1()
        {
            InitializeComponent();
            //centers the window to the screen so that the screen capture does not grab anything else
            CenterToScreen();
            //sets the background image to blank automatically
            defaultBackgroundImage = canvasBox.BackgroundImage;
            //reads the default data file immediately
            ReadInstances(SourceChoice);

        }
        private Label GenerateLabel()
        {   //Make a Label as needed by feeder function
            Label x = new Label();
            //adds the label to the groupBox
            this.canvasBox.Controls.Add(x);
            //@ location 1,1(top left corner)
            hold.X = xCoord;
            hold.Y = yCoord;
            x.Location = hold;
            //AutoSize must be enabled for least whitespace
            x.AutoSize = true;
            //Checks if a background shape is present
            if (ShapeBack)
            {
                x.BackColor = Color.White;
            }
            //creates toolTip which displays the count of each word when the mouse hovers over a label
            x.MouseHover += (s, e) =>
            {
                ToolTip cms = new ToolTip();
                cms.Show(QuantityArray[x.TabIndex].ToString(), canvasBox, x.Location, 2000);
            };
            //returns the label to the ArrangeLabel Function
            return x;
        }
        private void ArrangeLabel(Label x)
        { 
            //To arrange given Label with information across groupbox, in a randomized way 

            //must figure a way out to not let Labels lay on top of other existing Labels // 2/27/18
            //figured way to check interaction with other Labels // 2/27/18 - hours later

            //Must soon implement a way that is not random i.e. spiral, rectangular
            //random placement takes too long
            //not practical, fonts should start to get smaller faster with data from twitter crawler or other source
            // checks if button collides with another button, or the wall of the group box itself 2/28/18
            
            // Changes made to font size algorithm based off quantity!! Finally 4/4/18 
            // looks much better
            // Stencil is best font for readability and the least amount of wasted space
           
            // need to choose between algorithm of purely quantity based versus using the Log() function
           
            // Chose to use the Log algorithm as it looks most appealing to the eye - 4/15/18

            int MaxQuantity = 299; // max amount of words referenced in array // [0] to [299]
            int MaxMissesPerSet = 400; 
            //after 400 missed recurive calls, the zone will expand and missesPerSet is reset to 0
            //increment will go down by one every time until it reaches zero;
            if (setMisses > MaxMissesPerSet && Increment > 0)
            {
                Increment--;
                setMisses = 0;
            }
            
            //while you have not reached the last word asked for...keep placing words
            if (ArrayPlace < MaxQuantity)
            {
                //create an existing point to start with
                Point place = new Point();
                //border rectangles so words tdo not land on edge, incremental placemen
                //keeps this to a minimum already, but it is good to keep it 
                Rectangle rightBorder = new Rectangle(850, 1, 10, 589);
                Rectangle bottomBorder = new Rectangle(1, 580, 859, 589);
                //incremental placement algorithm - HERE IS THE MEAT AND POTATOES
                //sets placeholder point equal to the random values between the allowed X values
                //Defined as between the smallest X placement plus the incremental values
                //and 
                //the largest X placement minus the incremental values
                place.X = rnd.Next(MINWIDTH + (Increment * incWidth), MAXWIDTH - (Increment * incWidth));
                //sets placeholder point equal to the random values between the allowed Y values
                place.Y = rnd.Next(MINHEIGHT + (Increment * incHeight), MAXHEIGHT - (Increment * incHeight));
                //sets the location of the word to this new... partly random ... placement
                x.Location = place;
                //sets text to the current word within the word array
                x.Text = WordArray[ArrayPlace];
                //alternates colors between every 100
                if (ArrayPlace < 100)
                {
                    x.ForeColor = ColorArray[0];
                }
                else if (ArrayPlace < 200)
                {
                    x.ForeColor = ColorArray[1];
                }
                else
                {
                    x.ForeColor = ColorArray[2];
                }
                //Another MEAT AND POTATOES ALGORITHM
                //Font name is set to user input, default "Stencil"
                //Font size is set to the integer cast of a Log Op. of the actual quantity of the word
                //The Log operation makes all words visible and the highly common words not seem GIANT
                //Add 1 to the quantity in case of a log of (1), so not to equal zero
                //multiply by constant of 7 (fontMult) for words to be of readable size
                //fontMult can change based on inherent changes in sources
                x.Font = new Font(MasterFont, (int)(Math.Log((QuantityArray[ArrayPlace] + 1)) * fontMult));

               
                //Goes through the controls to find the groupBox Control
                foreach (Control c1 in this.Controls)
                {
                    if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                    {
                        //Once groupBox Control is found
                        //Go through each individual label, by order of tabIndex
                        foreach (Control c2 in c1.Controls)
                        {
                            //checks if this label is being compared to istelf, checks for collision with other labels, the right boarder, and the bottom boarder
                            if (!c2.Equals(x) && x.Bounds.IntersectsWith(c2.Bounds) || x.Bounds.IntersectsWith(rightBorder) || x.Bounds.IntersectsWith(bottomBorder))
                            {

                                    totalMisses++; //count displayed by the misses label after run button is clicked
                                    setMisses++; //how many collisions the program has in its current level of incrementation
                                    ArrangeLabel(x); //if there's a collision it keeps trying to place by calling the function recursively
                                
                            }

                        }
                    }
                }
            }
        }

        private void ArrangeLabel4Shape(Label x)
        {//To arrange Label with information across groupbox, in a randomized way, inside a given shape
            int HEARTminX = 100;
            int HEARTmaxX = 750;
            int HEARTminY = 30;
            int HEARTmaxY = 560;
            int HEARTincX = 20;
            int HEARTincY = 20;

            int MaxQuantity = 299;
            int MaxMissesPerSet = 400;

            Color WHITE = new Color();
            WHITE = Color.FromArgb(255, 255, 255, 255);

            if (setMisses > MaxMissesPerSet && Increment > 0)
            {
                Increment--;
                setMisses = 0;
            }
            if (ArrayPlace < MaxQuantity)
            {
                
                Point place = new Point();
                Rectangle rightBorder = new Rectangle(HEARTmaxX, 1, HEARTminX, 589);
                Rectangle bottomBorder = new Rectangle(1, HEARTmaxY, 859, HEARTminY);
                Rectangle topBorder = new Rectangle(1, 1, 859, HEARTminY);
                Rectangle leftBorder = new Rectangle(1, 1, HEARTminX, 589);
                place.X = rnd.Next(HEARTminX + (Increment * HEARTincX), HEARTmaxX - (Increment * HEARTincX));
                place.Y = rnd.Next(HEARTminY + (Increment * HEARTincY), HEARTmaxY - (Increment * HEARTincY));
                x.Location = place;
                x.Text = WordArray[ArrayPlace];
                if (ArrayPlace < 100)
                {
                    x.ForeColor = ColorArray[0];
                }
                else if (ArrayPlace < 200)
                {
                    x.ForeColor = ColorArray[1];
                }
                else
                {
                    x.ForeColor = ColorArray[2];
                }
                x.Font = new Font(MasterFont, (int)(Math.Log((QuantityArray[ArrayPlace] + 1)) * 6.25));
                x.Anchor = (AnchorStyles.Top | AnchorStyles.Left | AnchorStyles.Bottom | AnchorStyles.Right);
                foreach (Control c1 in this.Controls)
                {
                    if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                    {
                        foreach (Control c2 in c1.Controls)
                        {
                            //Color screenColor = GetColorFromScreen(place);
                            if (!c2.Equals(x) && x.Bounds.IntersectsWith(c2.Bounds) || 
                                x.Bounds.IntersectsWith(rightBorder) || 
                                x.Bounds.IntersectsWith(bottomBorder) || 
                                x.Bounds.IntersectsWith(leftBorder) || 
                                x.Bounds.IntersectsWith(topBorder))
                            {

                                totalMisses++; //count displayed by the misses label after run button is clicked
                                setMisses++; //how many collisions the program has in its current level of incrementation
                                ArrangeLabel4Shape(x); //if there's a collision it keeps trying to place by calling the function over and over
                            }
                      
                        }
                    }
                }
            }
        }
        private void RunButton_Click(object sender, EventArgs e)
        {
            //The real driver of all funcionality
            //Makes the cloud appear
            //Sets the necessary variables, then calls functions to create tag cloud

            //counter which is equal to amount of words user asks for
            decimal counter = 0;
           
            counter = UserNumWords.Value - 1;  // grabs value from the numerical updown in the UI
                                               //subtract by one for the array to work correctly
            int refreshStep = 25;//how often the program will ask to condese the words             
            int showStep = 50;//how often the program will ask the form to update() itself
            bool isShape = false;//sets the default value to not use a shaped background

            for (int i = 0; i <= counter; i++)//for loop which stops after all words
            {
                if (!ShapeBack)//if no shape detected progress as normal
                {
                    ArrangeLabel(GenerateLabel());
                }
                else //otherwise progress as if there is a shape
                {
                    ArrangeLabel(GenerateLabel());
                    isShape = true;//set off shape trigger
                }

                ArrayPlace++;//continue to next place in arrays
                if (ArrayPlace % refreshStep == 0)//condesnse every 25 words placed
                {
                    //Update();
                    Condense();
                    if (ArrayPlace % showStep == 0)//update screen every 50
                        Update();
                }
                
            }
            //Special coditions of condense applied when background shape exists
            if (isShape)//if there is a shaped background
            {
                while (cleanTheShape() > 0)//delete words that are outside the shape
                {                          //until there exist no more       
                    cleanTheShape();
                }
            }
            

            //makes sure to resent all buttons and constants that are neccessary
            ArrayPlace = 0; //reset to read starting at 0
            if (!ShapeBack)
            {
                BtnClean.Enabled = true; //allow user clean up if not using a shape
            }
            ClearButton.Enabled = true; //allow wipe of page
            btnScore.Enabled = true; //allow score to be recorded - not essential
            lblMisses.Text = totalMisses.ToString(); //display misses/inefficiencies
            RunButton.Enabled = false; //do not allow for another run until screen is cleared
            RunButton.BackColor = Color.Maroon; //make apparent by changing run to dark red
            changeBackgroundToolStripMenuItem.Enabled = false; //user is not allowed to change background shape
            openSourceToolStripMenuItem.Enabled = false; //user is not allowed to change the source of data
            //toolTips to notify user why they cannot use background and change source
            changeBackgroundToolStripMenuItem.ToolTipText = "must clear screen to enable shape modifications";
            openSourceToolStripMenuItem.ToolTipText = "must clear screen to enable source modifcation";
        }

        private void ClearButton_Click(object sender, EventArgs e)
        {
            //deletes every label on the screen
            //resets buttons, enables all UI, and clears scores and misses
            canvasBox.Controls.Clear();
            btnScore.Enabled = false;
            BtnClean.Enabled = false;
            totalWordQuantity = 0;
            Increment = 10;
            lblScore.Text = "Score N/A";
            lblMisses.Text = "";
            totalMisses = 0;
            RunButton.Enabled = true;
            RunButton.BackColor = Color.PaleGreen; //resets color of RUN to green
            changeBackgroundToolStripMenuItem.Enabled = true;
            openSourceToolStripMenuItem.Enabled = true;
            changeBackgroundToolStripMenuItem.ToolTipText = "";
            openSourceToolStripMenuItem.ToolTipText = "";
        }
        private void UserNumWords_ValueChanged(object sender, EventArgs e)
        {
            //makes sure the value of zero cannot be run
            if (UserNumWords.Value == 0)
            {
                RunButton.Enabled = false;
            }
            else
            {
                RunButton.Enabled = true;
            }
        }

        private void btnScore_Click(object sender, EventArgs e)
        {
            //Need for this function may be unnessesary 
            //Total white space is not a good mark, its only white space between words
            //that matters....idk how to just count that or if its possible
            int OffsetOnBoarder = 9; // I made bounding rectangles on the boarder, from X 850 to 859, and Y 589 to 580
            double usedArea = 0;
            double groupBoxArea = ((MAXHEIGHT - MINHEIGHT) - OffsetOnBoarder) * ((MAXWIDTH - MINWIDTH) - OffsetOnBoarder);
            double usedToWhite;
            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        usedArea += (c2.Size.Height * c2.Size.Width);
                    }
                }
            }
            usedToWhite = Math.Round(usedArea / groupBoxArea, 6);
            lblScore.Text = usedArea + " / " + groupBoxArea + " = " + (usedToWhite * 100) + "%";
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //could be useful to load things here
        }
        private void ReadInstances(int fileChoice)
        {
            //reads .txt file based off of user choice(int fileChoice)
            //creates new streamreader for both the word file and quantity file
            //while the count does not exceed 299(MaxWords) keep reading line by line 
            //into the WordArray[at count] and the QuantityArray[at count]
            //identical process for each choice ~~~ could probably be streamlined

            if (fileChoice == 1)
            {
                
                System.IO.StreamReader file =
                new System.IO.StreamReader(@"NBC2017review.txt");
                string line;
                int count = 0;
                while ((line = file.ReadLine()) != null && count < MaxWords)
                {
                    WordArray[count] = line;
                    count++;
                }

                string quantity;
                System.IO.StreamReader file2 =
                new System.IO.StreamReader(@"NBC2017reviewNumbers.txt");
                count = 0;
                while ((quantity = file2.ReadLine()) != null && count < MaxWords)
                {
                    QuantityArray[count] = Convert.ToInt32(quantity);
                    totalWordQuantity += QuantityArray[count];
                    count++;
                }
            }

            else if (fileChoice == 2)
            {
                System.IO.StreamReader file =
                new System.IO.StreamReader(@"LydiaBlogWords.txt");
                string line;
                int count = 0;
                while ((line = file.ReadLine()) != null && count < MaxWords)
                {
                    WordArray[count] = line;
                    count++;
                }

                string quantity;
                System.IO.StreamReader file2 =
                new System.IO.StreamReader(@"LydiaBlogNumbers.txt");
                count = 0;
                while ((quantity = file2.ReadLine()) != null && count < MaxWords)
                {
                    QuantityArray[count] = Convert.ToInt32(quantity);
                    totalWordQuantity += QuantityArray[count];
                    count++;
                }
            }
            else if (fileChoice == 3)
            {
                System.IO.StreamReader file =
                new System.IO.StreamReader(@"InceptionWords.txt");
                string line;
                int count = 0;
                while ((line = file.ReadLine()) != null && count < MaxWords)
                {
                    WordArray[count] = line;
                    count++;
                }

                string quantity;
                System.IO.StreamReader file2 =
                new System.IO.StreamReader(@"InceptionNumbers.txt");
                count = 0;
                while ((quantity = file2.ReadLine()) != null && count < MaxWords)
                {
                    QuantityArray[count] = Convert.ToInt32(quantity);
                    totalWordQuantity += QuantityArray[count];
                    count++;
                }
            }

            else if (fileChoice == 4)
            {
                System.IO.StreamReader file =
                new System.IO.StreamReader(@"StNorbertWords.txt");
                string line;
                int count = 0;
                while ((line = file.ReadLine()) != null && count < MaxWords)
                {
                    WordArray[count] = line;
                    count++;
                }

                string quantity;
                System.IO.StreamReader file2 =
                new System.IO.StreamReader(@"StNorbertNumbers.txt");
                count = 0;
                while ((quantity = file2.ReadLine()) != null && count < MaxWords)
                {
                    QuantityArray[count] = Convert.ToInt32(quantity);
                    totalWordQuantity += QuantityArray[count];
                    count++;
                }
            }

            else if (fileChoice == 5)
            {
                System.IO.StreamReader file =
                new System.IO.StreamReader(@"ComputerScienceWords.txt");
                string line;
                int count = 0;
                while ((line = file.ReadLine()) != null && count < MaxWords)
                {
                    WordArray[count] = line;
                    count++;
                }

                string quantity;
                System.IO.StreamReader file2 =
                new System.IO.StreamReader(@"ComputerScienceNumbers.txt");
                count = 0;
                while ((quantity = file2.ReadLine()) != null && count < MaxWords)
                {
                    QuantityArray[count] = Convert.ToInt32(quantity);
                    totalWordQuantity += QuantityArray[count];
                    count++;
                }
            }

            else if (fileChoice == 6)
            {
                System.IO.StreamReader file =
                new System.IO.StreamReader(@"ArtistStatementWords.txt");
                string line;
                int count = 0;
                while ((line = file.ReadLine()) != null && count < MaxWords)
                {
                    WordArray[count] = line;
                    count++;
                }

                string quantity;
                System.IO.StreamReader file2 =
                new System.IO.StreamReader(@"ArtistStatementNumbers.txt");
                count = 0;
                while ((quantity = file2.ReadLine()) != null && count < MaxWords)
                {
                    QuantityArray[count] = Convert.ToInt32(quantity);
                    totalWordQuantity += QuantityArray[count];
                    count++;
                }
            }
        }

        private void Condense()
        {
            //Function that moves labels closer together towards the middle
            //while keeping in mind zero collision and highest priority on whitespace 
            //This function mainly makes Hypothetical calls to IsCollision with given label  

            // McVey Has Helped me find the bug of Condense()!!!! Not checking for self - 4/20/18

            //offset for large words, and small words respectively
            //large words can only move small offsets, small can move much farther
            //techincally can check by 1, but takes a toll on time
            //int OFFSETtiny = 1;
            int OFFSETsmall = 5;
            int OFFSETmed = 20;
            int OFFSETlarge = 20;
            int OFFSETlargest = 40;
            int OFFSETHUGE = 80;

            //marks middle of groupBox 
            int MiddleX = 360;
            int MiddleY = 280;
            //850/2 = 425
            //580/2 = 290
            //since the above coordinates would be applied to the top left of each label
            //I changed the above numbers to be more centered. 
            //Considering that detail reflected in a more centered tagCloud

            //SAME FOREACH LOOP TO REACH EACH LABEL ~~~ could possibly refine but works as needed
         
            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        Point loc = c2.Location;//point to hold dummy numbers until if statement is actually true
                        //MessageBox.Show(c2.Text);   DO NOT DO WITH HIGH NUMBERS! // for debug only
                        //If the X location is to the right of the middle, see how far it can move left without collision
                        //try with largest values first, doing lazy evaluation
                        if (c2.Location.X > MiddleX)
                        {
                            if (!IsCollision(loc.X - OFFSETHUGE, loc.Y, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.X = loc.X - OFFSETHUGE;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X - OFFSETlargest, loc.Y, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.X = loc.X - OFFSETlargest;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X - OFFSETlarge, loc.Y, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.X = loc.X - OFFSETlarge;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X - OFFSETmed, loc.Y, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.X = loc.X - OFFSETmed;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X - OFFSETsmall, loc.Y, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.X = loc.X - OFFSETsmall;
                                c2.Location = loc;
                            }
                            //else if (!IsCollision(loc.X - OFFSETtiny, loc.Y, c2.Width, c2.Height, (Label)c2))
                            //{
                            //    loc.X = loc.X - OFFSETtiny;
                            //    c2.Location = loc;
                            //}
                        }
                        else
                        {   //The X location must be to the left of the middle, see how far it can move right without collision
                            //try with largest values first, doing lazy evaluation
                            if (!IsCollision(loc.X + OFFSETHUGE, loc.Y, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.X = loc.X + OFFSETHUGE;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X + OFFSETlargest, loc.Y , c2.Width, c2.Height, (Label)c2))
                            {
                                loc.X = loc.X + OFFSETlargest;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X + OFFSETlarge, loc.Y, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.X = loc.X + OFFSETlarge;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X + OFFSETmed, loc.Y, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.X = loc.X + OFFSETmed;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X + OFFSETsmall, loc.Y, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.X = loc.X + OFFSETsmall;
                                c2.Location = loc;
                            }
                            //else if (!IsCollision(loc.X + OFFSETtiny, loc.Y, c2.Width, c2.Height, (Label)c2))
                            //{
                            //    loc.X = loc.X + OFFSETtiny;
                            //    c2.Location = loc;
                            //}
                        }
                        if (c2.Location.Y > MiddleY)
                        {
                            //If the Y location is Below the middle, see how far it can move up without collision
                            //try with largest values first, doing lazy evaluation
                            if (!IsCollision(loc.X , loc.Y - OFFSETHUGE, c2.Width, c2.Height, (Label)c2))
                            { 
                                loc.Y = loc.Y - OFFSETHUGE;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X, loc.Y - OFFSETlargest, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.Y = loc.Y - OFFSETlargest;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X, loc.Y - OFFSETlarge, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.Y = loc.Y - OFFSETlarge;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X, loc.Y - OFFSETmed, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.Y = loc.Y - OFFSETmed;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X, loc.Y - OFFSETsmall, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.Y = loc.Y - OFFSETsmall;
                                c2.Location = loc;
                            }
                            //else if (!IsCollision(loc.X , loc.Y - OFFSETtiny, c2.Width, c2.Height, (Label)c2))
                            //{
                            //    loc.Y = loc.Y - OFFSETtiny;
                            //    c2.Location = loc;
                            //}
                        }
                        else
                        {
                            //The Y location must be above the middle, see how far it can move down without collision
                            //try with largest values first, doing lazy evaluation
                            if (!IsCollision(loc.X, loc.Y + OFFSETHUGE, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.Y = loc.Y + OFFSETHUGE;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X, loc.Y + OFFSETlargest, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.Y = loc.Y + OFFSETlargest;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X, loc.Y + OFFSETlarge, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.Y = loc.Y + OFFSETlarge;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X, loc.Y + OFFSETmed, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.Y = loc.Y + OFFSETmed;
                                c2.Location = loc;
                            }
                            else if (!IsCollision(loc.X, loc.Y + OFFSETsmall, c2.Width, c2.Height, (Label)c2))
                            {
                                loc.Y = loc.Y + OFFSETsmall;
                                c2.Location = loc;
                            }
                            //else if (!IsCollision(loc.X, loc.Y + OFFSETtiny, c2.Width, c2.Height, (Label)c2))
                            //{
                            //    loc.Y = loc.Y + OFFSETtiny;
                            //    c2.Location = loc;
                            //}
                        }
                        Update(); //update after movement
                        //otherwise the cloud looks much sloppier
                    }
                }
            }
        }

        private void BtnClean_Click(object sender, EventArgs e)
        {
           //made this just a call to one main function
           //allow user to condense as they desire, if not using a shape
           Condense();
        }

        private Boolean IsCollision(int LocationX, int LocationY, int sizeX, int sizeY, Label lbl)
        {
            //Collision function - Checks to see if given label with new coordinates will
            //collide with an existing label. If this function returns true, it means that
            //it collided with an existing label
            //otherwise it will return false, resulting in a placed label

            //creates rectangle that stands in place of the label
            //for efficiency and allocation reasons - do not want another label to be drawn/moved
            Rectangle fromGiven = new Rectangle(LocationX, LocationY, sizeX, sizeY);

            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        if(!c2.Equals(lbl)) //For the longest time I did not check for collision of itself ;(
                                            //Thank you McVey
                        if (c2.Bounds.IntersectsWith(fromGiven))
                        {
                            return true;
                        }
                    }
                }
            }
            return false;
        }

        private void radBtnBackColor_CheckedChanged(object sender, EventArgs e)
        {
            //debug feature to display how much space is wasted with label controls
            if (radBtnBackColor.Checked == true)
            {
                foreach (Control c1 in this.Controls)
                {
                    if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                    {
                        foreach (Control c2 in c1.Controls)
                        {
                            c2.BackColor = Color.DimGray;
                        }
                    }
                }
            }
            Update();
        }

        private void radBackColorOff_CheckedChanged(object sender, EventArgs e)
        {//does not work correctly
            if (radBtnBackColor.Checked == false)
            {
                foreach (Control c1 in this.Controls)
                {
                    if (c1.ToString().StartsWith("System.Windows.Forms.Groupbox"))
                    {
                        foreach (Control c2 in c1.Controls)
                        {
                            c2.BackColor = Color.White;
                        }
                    }
                }
            }
            Update();
        }

        private void saveCloudAsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            //saves a screenshot of the groupbox control, which contains the wordTagCloud
            //Creates a bitmap of the groupbox, based off the client rectangle
            //Has sometimes saved a snapshot with the saveDialog box still in the frame
            //^^not good

            Bitmap bitmap = new Bitmap(canvasBox.Width, canvasBox.Height);
            SaveFileDialog sfd = new SaveFileDialog();
            sfd.InitialDirectory = "C:\\Users\\admin\\Desktop\\CSCICapstone2.0.1\\CSCICapstone2.0.1\\bin\\Debug";
            sfd.Filter = "Images|*.png;*.bmp;*.jpg";
            ImageFormat format = ImageFormat.Png;
            if (sfd.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                string ext = System.IO.Path.GetExtension(sfd.FileName);
                switch (ext)
                {
                    case ".jpg":
                        format = ImageFormat.Jpeg;
                        break;
                    case ".bmp":
                        format = ImageFormat.Bmp;
                        break;
                }
                
                Graphics g = Graphics.FromImage(bitmap);
                Rectangle rect = canvasBox.RectangleToScreen(canvasBox.ClientRectangle);
                rect.Y = rect.Y + 5;
                g.CopyFromScreen(rect.Location, Point.Empty, canvasBox.Size);
            }
            else
            {
                return;
            }
            bitmap.Save(sfd.FileName, format);
        }

        public Color GetColorFromScreen (Point P)
        {   //Function for finding the pixel color at a given point
            //used to check if a label is in/out of shape 
            

            Rectangle rect = new Rectangle(P, new Size(2, 2));
            
            Color grab = map.GetPixel(P.X, P.Y);
            return grab;
        }


        private int cleanTheShape()
        {
            //Function deletes labels that exist outside of the shape
            //uses getColorFromScreen to determine if label needs to be deleted
            //if color behind label is white - keep it!
            //if color behind label is default Control Color - delete it!
            //if deletes a label, the counter outOfShape goes up by one
            //return outOfShape

            int outOfShape = 0;
            Color WHITE = new Color();        
            WHITE = Color.FromArgb(255, 255, 255, 255);
            Point middle = new Point();
            Point middleTop = new Point();

            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        //check color at the top left of label
                        Color Screengrab = GetColorFromScreen(c2.Location);
                        if (Screengrab != WHITE)
                        {
                            //MessageBox.Show("should delete" + c2.Text);
                            c2.Dispose();
                            outOfShape++;
                        }
                        //check at the middle of the label
                        middle.X = c2.Location.X + (int) (.5 * c2.Width);
                        middle.Y = c2.Location.Y + (int) (.5 * c2.Height);
                        Screengrab = GetColorFromScreen(middle);
                        if (Screengrab != WHITE)
                        {
                            //MessageBox.Show("should delete" + c2.Text);
                            c2.Dispose();
                            outOfShape++;
                        }
                        //check at the middleTop of the label
                        middleTop.X = c2.Location.X + (int) (.5 *c2.Width);
                        middleTop.Y = c2.Location.Y;
                        Screengrab = GetColorFromScreen(middleTop);
                        if (Screengrab != WHITE)
                        {
                            //MessageBox.Show("should delete" + c2.Text);
                            c2.Dispose();
                            outOfShape++;
                        }
                    }
                }
            }
        return outOfShape; //return the number of labels deleted
        }

        private void heartToolStripMenuItem_Click(object sender, EventArgs e)
        {
            //Menu Tool strip for the UI that lets the user pic a background
            //Picks the heart Background
            //Disables the "Clean It Up" button
            //all of these are specific to the shapes I have designated

            original = Image.FromFile("Heart2Control.png");
            map = new Bitmap(original, canvasBox.Width, canvasBox.Height);
            canvasBox.BackgroundImage = original;
            ShapeBack = true;
            heartToolStripMenuItem.Checked = true;

            blankToolStripMenuItem.Checked = false;
            arrowToolStripMenuItem.Checked = false;
            starToolStripMenuItem.Checked = false;
            lightningBoltToolStripMenuItem.Checked = false;
            calloutToolStripMenuItem.Checked = false;

            BtnClean.Enabled = false;
        }

        private void calloutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            original = Image.FromFile("WordBubbleControl.png");
            map = new Bitmap(original, canvasBox.Width, canvasBox.Height);
            canvasBox.BackgroundImage = original;
            ShapeBack = true;
            calloutToolStripMenuItem.Checked = true;

            blankToolStripMenuItem.Checked = false;
            arrowToolStripMenuItem.Checked = false;
            starToolStripMenuItem.Checked = false;
            lightningBoltToolStripMenuItem.Checked = false;
            heartToolStripMenuItem.Checked = false;

            BtnClean.Enabled = false;
        }

        private void lightningBoltToolStripMenuItem_Click(object sender, EventArgs e)
        {
            original = Image.FromFile("LightningControl1.png");
            map = new Bitmap(original, canvasBox.Width, canvasBox.Height);
            canvasBox.BackgroundImage = original;
            ShapeBack = true;
            lightningBoltToolStripMenuItem.Checked = true;

            blankToolStripMenuItem.Checked = false;
            arrowToolStripMenuItem.Checked = false;
            starToolStripMenuItem.Checked = false;
            calloutToolStripMenuItem.Checked = false;
            heartToolStripMenuItem.Checked = false;

            BtnClean.Enabled = false;
        }

        private void starToolStripMenuItem_Click(object sender, EventArgs e)
        {
            original = Image.FromFile("StarControl.png");
            map = new Bitmap(original, canvasBox.Width, canvasBox.Height);
            canvasBox.BackgroundImage = original;
            ShapeBack = true;
            starToolStripMenuItem.Checked = true;

            blankToolStripMenuItem.Checked = false;
            arrowToolStripMenuItem.Checked = false;
            lightningBoltToolStripMenuItem.Checked = false;
            calloutToolStripMenuItem.Checked = false;
            heartToolStripMenuItem.Checked = false;

            BtnClean.Enabled = false;
        }
        private void arrowToolStripMenuItem_Click(object sender, EventArgs e)
        {
            original = Image.FromFile("RightArrowControl.png");
            map = new Bitmap(original, canvasBox.Width, canvasBox.Height);
            canvasBox.BackgroundImage = original;
            ShapeBack = true;
            arrowToolStripMenuItem.Checked = true;

            blankToolStripMenuItem.Checked = false;
            starToolStripMenuItem.Checked = false;
            lightningBoltToolStripMenuItem.Checked = false;
            calloutToolStripMenuItem.Checked = false;
            heartToolStripMenuItem.Checked = false;

            BtnClean.Enabled = false;
        }

        private void blankToolStripMenuItem_Click(object sender, EventArgs e)
        {
            original = Image.FromFile("Control.png");
            map = new Bitmap(original, canvasBox.Width, canvasBox.Height);
            canvasBox.BackgroundImage = original;
            ShapeBack = false;
            blankToolStripMenuItem.Checked = true;

            arrowToolStripMenuItem.Checked = false;
            starToolStripMenuItem.Checked = false;
            lightningBoltToolStripMenuItem.Checked = false;
            calloutToolStripMenuItem.Checked = false;
            heartToolStripMenuItem.Checked = false;

            BtnClean.Enabled = false;
        }
        
        private void stencilToolStripMenuItem_Click(object sender, EventArgs e)
        {
            //Sets the font to the choosen font - Re-runs the whole program with new font
            MasterFont = FontArray[0];

            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        c2.Font = new Font(MasterFont, c2.Font.Size);
                    }
                }
            }

            timesNewRomanToolStripMenuItem.Checked = false;
            microsoftSansSerifToolStripMenuItem.Checked = false;
            wingdingsToolStripMenuItem.Checked = false;
            impactToolStripMenuItem.Checked = false;
            harlowSolidToolStripMenuItem.Checked = false;
            cooperToolStripMenuItem.Checked = false;
            comicSansMSToolStripMenuItem.Checked = false;

            stencilToolStripMenuItem.Checked = true;

            ClearButton_Click(sender, e);
            RunButton_Click(sender, e);

            //Condense();
        }

        private void timesNewRomanToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MasterFont = FontArray[1];

            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        c2.Font = new Font(MasterFont, c2.Font.Size);
                    }
                }
            }

            stencilToolStripMenuItem.Checked = false;
            microsoftSansSerifToolStripMenuItem.Checked = false;
            wingdingsToolStripMenuItem.Checked = false;
            impactToolStripMenuItem.Checked = false;
            harlowSolidToolStripMenuItem.Checked = false;
            cooperToolStripMenuItem.Checked = false;
            comicSansMSToolStripMenuItem.Checked = false;

            timesNewRomanToolStripMenuItem.Checked = true;

            ClearButton_Click(sender, e);
            RunButton_Click(sender, e);

            //Condense();
        }

        private void microsoftSansSerifToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MasterFont = FontArray[2];

            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        c2.Font = new Font(MasterFont, c2.Font.Size);
                    }
                }
            }

            stencilToolStripMenuItem.Checked = false;
            timesNewRomanToolStripMenuItem.Checked = false;
            wingdingsToolStripMenuItem.Checked = false;
            impactToolStripMenuItem.Checked = false;
            harlowSolidToolStripMenuItem.Checked = false;
            cooperToolStripMenuItem.Checked = false;
            comicSansMSToolStripMenuItem.Checked = false;

            microsoftSansSerifToolStripMenuItem.Checked = true;

            ClearButton_Click(sender, e);
            RunButton_Click(sender, e);

            //Condense();
        }

        private void wingdingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MasterFont = FontArray[3];

            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        c2.Font = new Font(MasterFont, c2.Font.Size);
                    }
                }
            }

            stencilToolStripMenuItem.Checked = false;
            timesNewRomanToolStripMenuItem.Checked = false;
            microsoftSansSerifToolStripMenuItem.Checked = false;
            impactToolStripMenuItem.Checked = false;
            harlowSolidToolStripMenuItem.Checked = false;
            cooperToolStripMenuItem.Checked = false;
            comicSansMSToolStripMenuItem.Checked = false;

            wingdingsToolStripMenuItem.Checked = true;

            ClearButton_Click(sender, e);
            RunButton_Click(sender, e);

            //Condense();
        }

        private void impactToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MasterFont = FontArray[4];

            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        c2.Font = new Font(MasterFont, c2.Font.Size);
                    }
                }
            }

            stencilToolStripMenuItem.Checked = false;
            timesNewRomanToolStripMenuItem.Checked = false;
            microsoftSansSerifToolStripMenuItem.Checked = false;
            wingdingsToolStripMenuItem.Checked = false;
            harlowSolidToolStripMenuItem.Checked = false;
            cooperToolStripMenuItem.Checked = false;
            comicSansMSToolStripMenuItem.Checked = false;

            impactToolStripMenuItem.Checked = true;

            ClearButton_Click(sender, e);
            RunButton_Click(sender, e);

            //Condense();
        }

        private void harlowSolidToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MasterFont = FontArray[5];

            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        c2.Font = new Font(MasterFont, c2.Font.Size);
                    }
                }
            }

            stencilToolStripMenuItem.Checked = false;
            timesNewRomanToolStripMenuItem.Checked = false;
            microsoftSansSerifToolStripMenuItem.Checked = false;
            wingdingsToolStripMenuItem.Checked = false;
            impactToolStripMenuItem.Checked = false;
            cooperToolStripMenuItem.Checked = false;
            comicSansMSToolStripMenuItem.Checked = false;

            harlowSolidToolStripMenuItem.Checked = true;

            ClearButton_Click(sender, e);
            RunButton_Click(sender, e);

            //Condense();
        }

        private void cooperToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MasterFont = FontArray[6];

            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        c2.Font = new Font(MasterFont, c2.Font.Size);
                    }
                }
            }

            stencilToolStripMenuItem.Checked = false;
            timesNewRomanToolStripMenuItem.Checked = false;
            microsoftSansSerifToolStripMenuItem.Checked = false;
            wingdingsToolStripMenuItem.Checked = false;
            impactToolStripMenuItem.Checked = false;
            harlowSolidToolStripMenuItem.Checked = false;
            comicSansMSToolStripMenuItem.Checked = false;

            cooperToolStripMenuItem.Checked = true;

            ClearButton_Click(sender, e);
            RunButton_Click(sender, e);

            //Condense();
        }

        private void comicSansMSToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MasterFont = FontArray[7];

            foreach (Control c1 in this.Controls)
            {
                if (c1.ToString().StartsWith("System.Windows.Forms.GroupBox"))
                {
                    foreach (Control c2 in c1.Controls)
                    {
                        c2.Font = new Font(MasterFont, c2.Font.Size);
                    }
                }
            }

            stencilToolStripMenuItem.Checked = false;
            timesNewRomanToolStripMenuItem.Checked = false;
            microsoftSansSerifToolStripMenuItem.Checked = false;
            wingdingsToolStripMenuItem.Checked = false;
            impactToolStripMenuItem.Checked = false;
            harlowSolidToolStripMenuItem.Checked = false;
            cooperToolStripMenuItem.Checked = false;

            comicSansMSToolStripMenuItem.Checked = true;

            ClearButton_Click(sender, e);
            RunButton_Click(sender, e);

            //Condense();
        }

        private void nBC2017InReviewToolStripMenuItem_Click(object sender, EventArgs e)
        {
            //Sets the source data of the tag cloud generator to what the user chooses
            //default value is 1 for the NBC2017YearInReview article

            SourceChoice = 1;
            ReadInstances(SourceChoice);

            spainBlogToolStripMenuItem.Checked = false;
            inceptionExplainedToolStripMenuItem.Checked = false;
            stNorbertWikiToolStripMenuItem.Checked = false;
            compSciWikiToolStripMenuItem.Checked = false;
            artistsStatementsToolStripMenuItem.Checked = false;

            nBC2017InReviewToolStripMenuItem.Checked = true;
            fontMult = 7;
        }

        private void spainBlogToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SourceChoice = 2;
            ReadInstances(SourceChoice);
            
            inceptionExplainedToolStripMenuItem.Checked = false;
            stNorbertWikiToolStripMenuItem.Checked = false;
            compSciWikiToolStripMenuItem.Checked = false;
            artistsStatementsToolStripMenuItem.Checked = false;
            nBC2017InReviewToolStripMenuItem.Checked = false;

            spainBlogToolStripMenuItem.Checked = true;
            fontMult = 7;
        }

        private void inceptionExplainedToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SourceChoice = 3;
            ReadInstances(SourceChoice);
            
            stNorbertWikiToolStripMenuItem.Checked = false;
            compSciWikiToolStripMenuItem.Checked = false;
            artistsStatementsToolStripMenuItem.Checked = false;
            nBC2017InReviewToolStripMenuItem.Checked = false;
            spainBlogToolStripMenuItem.Checked = false;

            inceptionExplainedToolStripMenuItem.Checked = true;
            fontMult = 8;
        }

        private void stNorbertWikiToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SourceChoice = 4;
            ReadInstances(SourceChoice);

            inceptionExplainedToolStripMenuItem.Checked = false;
            compSciWikiToolStripMenuItem.Checked = false;
            artistsStatementsToolStripMenuItem.Checked = false;
            nBC2017InReviewToolStripMenuItem.Checked = false;
            spainBlogToolStripMenuItem.Checked = false;

            stNorbertWikiToolStripMenuItem.Checked = true;
            fontMult = 7;
        }

        private void compSciWikiToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SourceChoice = 5;
            ReadInstances(SourceChoice);

            inceptionExplainedToolStripMenuItem.Checked = false;
            stNorbertWikiToolStripMenuItem.Checked = false;
            artistsStatementsToolStripMenuItem.Checked = false;
            nBC2017InReviewToolStripMenuItem.Checked = false;
            spainBlogToolStripMenuItem.Checked = false;

            compSciWikiToolStripMenuItem.Checked = true;
            fontMult = 5;
        }

        private void artistsStatementsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SourceChoice = 6;
            ReadInstances(SourceChoice);

            inceptionExplainedToolStripMenuItem.Checked = false;
            stNorbertWikiToolStripMenuItem.Checked = false;
            compSciWikiToolStripMenuItem.Checked = false;
            nBC2017InReviewToolStripMenuItem.Checked = false;
            spainBlogToolStripMenuItem.Checked = false;

            artistsStatementsToolStripMenuItem.Checked = true;
            fontMult = 7;
        }

        private void changeBackgroundToolStripMenuItem_MouseHover(object sender, EventArgs e)
        {
            //notifies the user why they cannot change the background while there is 
            //an active tagcloud
            ToolTip changeOptions = new ToolTip();
            changeOptions.Show(changeBackgroundToolStripMenuItem.ToolTipText, this, Location, 5000);
        }

        private void openSourceToolStripMenuItem_MouseHover(object sender, EventArgs e)
        {
            //notifies the user why they cannot change the source while there is 
            //an active tagcloud
            ToolTip openSource = new ToolTip();
            openSource.Show(changeBackgroundToolStripMenuItem.ToolTipText, this, Location, 5000);
        }

        //plans to create one step color changing toolStrip
    }
}


